summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmskysphereedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmskysphereedit.h')
-rw-r--r--kpovmodeler/pmskysphereedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmskysphereedit.h b/kpovmodeler/pmskysphereedit.h
index 2f8c811e..1135e583 100644
--- a/kpovmodeler/pmskysphereedit.h
+++ b/kpovmodeler/pmskysphereedit.h
@@ -38,9 +38,9 @@ class PMSkySphereEdit : public PMTextureBaseEdit
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMSkySphereEdit with tqparent and name
*/
- PMSkySphereEdit( TQWidget* tqparent, const char* name = 0 );
+ PMSkySphereEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -38,9 +38,9 @@ class PMSkySphereEdit : public PMTextureBaseEdit
public:
/**
- * Creates a PMSkySphereEdit with tqparent and name
+ * Creates a PMSkySphereEdit with parent and name
*/